@@ -9,9 +9,9 @@
 #' replace existing parameters.
 #' 
 #' @param x Result from [run_model()].
-#' @param model Name or index of model to recompute.
+#' @param strategy Name or index of model to recompute.
 #' @param newdata a data.frame whose names match parameters 
-#'   names. `model` will be evaluated iteratively, 
+#'   names. `strategy` will be evaluated iteratively, 
 #'   taking successive values from each row.
 #'   
 #' @return A data.frame containing the values of 
@@ -23,7 +23,6 @@
 #' @keywords internal
 eval_strategy_newdata <- function(x, strategy = 1, newdata) {
   strategy <- check_strategy_index(x = x, i = strategy)
-  
   cycles <- get_cycles(x)
   init <- get_uneval_init(x)
   inflow <- get_inflow(x)
@@ -101,6 +100,26 @@ eval_strategy_newdata <- function(x, strategy = 1, newdata) {
   res
 }
 
+get_new_surv_parameters <- function(new_parameters, env = getOption("heemod.env")){
+  surv_new_parameters <- Filter(function(x) inherits(x, "surv_psa"), new_parameters)
+  
+  new_list <- map(surv_new_parameters,1)
+  
+  quo_surv <- Filter(is_quosure, new_list)
+  non_quo_surv <- new_list[setdiff(names(new_list), names(quo_surv))]
+  
+  nm <- map(quo_surv, function(x){
+    deparse(get_expr(x))
+  })
+  data_surv <- map(seq_along(quo_surv), function(i){
+    get_env(quo_surv[[i]])[[nm[[i]]]]
+  }) %>% setNames(nm)
+  
+  list2env(c(non_quo_surv, data_surv), envir = env)
+  
+  surv_new_parameters
+}
+
 eval_newdata <- function(new_parameters, strategy, old_parameters,
                          cycles, init, method, inflow,
                          strategy_name, expand_limit) {
@@ -110,6 +129,8 @@ eval_newdata <- function(new_parameters, strategy, old_parameters,
     new_parameters
   )
   
+  new_parameters <- setdiff(new_parameters, get_new_surv_parameters(new_parameters))
+  
   tidy_new_param <- to_dots(new_parameters)
   
   parameters <- utils::modifyList(
