@@ -21,8 +21,8 @@ summary.run_model <- function(object, threshold = NULL, ...) {
   
   res_values <- get_model_results(object) %>% 
     dplyr::select(
-      -.data$.cost,
-      -.data$.effect
+      -.cost,
+      -.effect
     ) %>% 
     as.data.frame()
   
@@ -34,7 +34,7 @@ summary.run_model <- function(object, threshold = NULL, ...) {
     
     res_nmb <- object %>% 
       scale.run_model(center = FALSE) %>% 
-      dplyr::select(.data$.strategy_names, .data$.cost, .data$.effect) %>% 
+      dplyr::select(.strategy_names, .cost, .effect) %>% 
       as.data.frame()
     
     res_nmb_strat <- character()
@@ -220,8 +220,8 @@ print_results <- function(res_values, res_comp, res_nmb) {
   cat("Values:\n\n")
   rownames(res_values) <- res_values$.strategy_names
   res_values <- dplyr::select(res_values,
-                              -.data$.strategy_names,
-                              -.data$.n_indiv)
+                              -.strategy_names,
+                              -.n_indiv)
   print(res_values)
   
   if (! is.null(res_nmb)) {
@@ -230,9 +230,9 @@ print_results <- function(res_values, res_comp, res_nmb) {
     f <- function(x) x - min(x)
     res_nmb <- res_nmb %>% 
       dplyr::select(
-        -.data$.strategy_names,
-        -.data$.cost,
-        -.data$.effect
+        -.strategy_names,
+        -.cost,
+        -.effect
       ) %>% 
       dplyr::mutate_all(f)
     
@@ -247,8 +247,8 @@ print_results <- function(res_values, res_comp, res_nmb) {
     
     rownames(res_comp) <- res_comp$.strategy_names
     res_comp <- res_comp %>% 
-      dplyr::select(.data$.dcost, .data$.deffect,
-                    .data$.icer, .data$.dref)
+      dplyr::select(.dcost, .deffect,
+                    .icer, .dref)
     res_comp$.icer <- format(res_comp$.icer)
     res_comp$.icer[res_comp$.icer == "NA"] <- "-"
     res_comp <- res_comp[-1, ]
