@@ -758,4 +758,10 @@ c.uneval_parameters <- function(...){
     inherits(x, "uneval_parameters")
   }) %>% as.logical()))
   structure(.Data = vctrs::vec_c(...), class = class(.dots[[1]]))
+}
+
+setdiff <- function (x, y) {
+  u <- as.vector(x)
+  v <- as.vector(y)
+  u[!duplicated(unclass(u)) & (match(u, v, 0L) == 0L)]
 }
\ No newline at end of file
