@@ -32,7 +32,7 @@ param <- define_parameters(
     
     # age-related mortality rate
     sex_cat = ifelse(sex == 0, "FMLE", "MLE"),
-    mr = get_who_mr(age, sex_cat, local = TRUE),
+    mr = get_who_mr(age, sex_cat),
     
     # state values
     u_SuccessP = .85,
